
This is the client of High Energy Physics AI platform (HAI).

The hai platform is a gprc service that provides artificial intellegence algorithms.

THe hai_client is calling tool that support languages (python, java, c/c++ etc.) and systems (linux, macos, windows etc.)

## Get Started

### start server
In the server computer with GPU. 
```
pip install hepai
hai server start  # start server
```

### run client
In the client computer.
```
pip install hepai-client
```

